[−][src]Function mdbook::utils::id_from_content
pub fn id_from_content(content: &str) -> String
Generate an ID for use with anchors which is derived from a "normalised" string.
pub fn id_from_content(content: &str) -> String
Generate an ID for use with anchors which is derived from a "normalised" string.